==> igniteui-webcomponents-core-4.0.2.tgz: package/esm5/lib/WebPanePinnedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebPanePinnedEventArgsDescription } from "./WebPanePinnedEventArgsDescription";
/**
 * @hidden
 */
var WebPanePinnedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPanePinnedEventArgsDescriptionMetadata, _super);
    function WebPanePinnedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPanePinnedEventArgsDescriptionMetadata.b = function (a) {
        if (WebPanePinnedEventArgsDescriptionMetadata.a == null) {
            WebPanePinnedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPanePinnedEventArgsDescriptionMetadata.c(WebPanePinnedEventArgsDescriptionMetadata.a);
        }
        if (a.j(WebPanePinnedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPanePinnedEventArgsDescriptionMetadata.a);
        WebContentPaneDescriptionMetadata.d(a);
    };
    WebPanePinnedEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PanePinnedEventArgs");
        a.item("SourcePane", "ExportedType:WebContentPane");
        a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
        a.item("NewValue", "Boolean");
        a.item("Location", "ExportedType:string:PanePinnedEventArgsLocation");
        a.item("Location@names", "Top;Bottom;Left;Right");
    };
    WebPanePinnedEventArgsDescriptionMetadata.d = function (a) {
        WebPanePinnedEventArgsDescriptionMetadata.b(a);
        a.aa("WebPanePinnedEventArgs", function () { return new WebPanePinnedEventArgsDescription(); });
        a.z("WebPanePinnedEventArgs", WebPanePinnedEventArgsDescriptionMetadata.a);
    };
    WebPanePinnedEventArgsDescriptionMetadata.$t = markType(WebPanePinnedEventArgsDescriptionMetadata, 'WebPanePinnedEventArgsDescriptionMetadata');
    WebPanePinnedEventArgsDescriptionMetadata.a = null;
    return WebPanePinnedEventArgsDescriptionMetadata;
}(Base));
export { WebPanePinnedEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-4.0.4.tgz: package/esm5/lib/WebPanePinnedEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebContentPaneDescriptionMetadata } from "./WebContentPaneDescriptionMetadata";
import { WebPanePinnedEventArgsDescription } from "./WebPanePinnedEventArgsDescription";
/**
 * @hidden
 */
var WebPanePinnedEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPanePinnedEventArgsDescriptionMetadata, _super);
    function WebPanePinnedEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPanePinnedEventArgsDescriptionMetadata.b = function (a) {
        if (WebPanePinnedEventArgsDescriptionMetadata.a == null) {
            WebPanePinnedEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPanePinnedEventArgsDescriptionMetadata.c(WebPanePinnedEventArgsDescriptionMetadata.a);
        }
        if (a.k(WebPanePinnedEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPanePinnedEventArgsDescriptionMetadata.a);
        WebContentPaneDescriptionMetadata.d(a);
    };
    WebPanePinnedEventArgsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:PanePinnedEventArgs");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        a.item("SourcePane", "ExportedType:WebContentPane");
        a.item("Panes", "Collection:WebContentPane:ContentPaneCollection:WebContentPane");
        a.item("NewValue", "Boolean");
        a.item("Location", "ExportedType:string:PanePinnedEventArgsLocation");
        a.item("Location@names", "Top;Bottom;Left;Right");
    };
    WebPanePinnedEventArgsDescriptionMetadata.d = function (a) {
        WebPanePinnedEventArgsDescriptionMetadata.b(a);
        a.ac("WebPanePinnedEventArgs", function () { return new WebPanePinnedEventArgsDescription(); });
        a.ab("WebPanePinnedEventArgs", WebPanePinnedEventArgsDescriptionMetadata.a);
    };
    WebPanePinnedEventArgsDescriptionMetadata.$t = markType(WebPanePinnedEventArgsDescriptionMetadata, 'WebPanePinnedEventArgsDescriptionMetadata');
    WebPanePinnedEventArgsDescriptionMetadata.a = null;
    return WebPanePinnedEventArgsDescriptionMetadata;
}(Base));
export { WebPanePinnedEventArgsDescriptionMetadata };
